@@ -45,7 +45,7 @@ export class ListOrganizationWorkspacesController {
   /**
    * Service for displaying notifications.
    */
-  private cheNotification: any;
+  private cheNotification: CheNotification;
   /**
    * Service for displaying dialogs.
    */
@@ -250,9 +250,9 @@ export class ListOrganizationWorkspacesController {
           this.cheNotification.showError('Delete failed.');
         } else {
           if (numberToDelete === 1) {
-            this.cheNotification.showInfo(workspaceName + ' has been removed.');
+            this.cheNotification.showSuccess(workspaceName + ' has been removed.');
           } else {
-            this.cheNotification.showInfo('Selected workspaces have been removed.');
+            this.cheNotification.showSuccess('Selected workspaces have been removed.');
           }
         }
       });
