@@ -42,9 +42,9 @@ export const jsonBranding = JSON.stringify({
   'docs': {
     'devfile': 'https://www.eclipse.org/che/docs/che-7/making-a-workspace-portable-using-a-devfile/',
     'workspace': 'https://www.eclipse.org/che/docs/che-7/workspaces-overview/',
-    'factory': 'https://www.eclipse.org/che/docs/factories-getting-started.html',
-    'organization': 'https://www.eclipse.org/che/docs/organizations.html',
-    'converting': 'https://www.eclipse.org/che/docs/che-7/converting-a-che-6-workspace-to-a-che-7-devfile/',
+    'factory': 'https://www.eclipse.org/che/docs/che-7',
+    'organization': 'https://www.eclipse.org/che/docs/che-7',
+    'converting': 'https://www.eclipse.org/che/docs/che-7',
     'certificate': 'https://www.eclipse.org/che/docs/che-7/importing-certificates-to-browsers/',
     'general': 'https://www.eclipse.org/che/docs/che-7',
     'storageTypes': 'https://www.eclipse.org/che/docs/che-7/configuring-storage-types/',
@@ -53,7 +53,7 @@ export const jsonBranding = JSON.stringify({
   'configuration': {
     'menu': {
       'disabled': [
-        'organizations'
+        'organizations', 'factories'
       ]
     },
     'features': {
@@ -61,7 +61,8 @@ export const jsonBranding = JSON.stringify({
     },
     'prefetch': {
       'resources': []
-    }
+    },
+    'cheCliTool': 'chectl'
   },
   'footer': {
     'content': '',
