@@ -74,8 +74,9 @@ import {CheToggleButton} from './toggle-button/che-toggle-button.directive';
 import {CheToggle} from './toggle-button/che-toggle.directive';
 import {CheToolbar} from './toolbar/che-toolbar.directive';
 import {CheErrorNotification} from './notification/che-error-notification.directive';
-import {CheInfoNotification} from './notification/che-info-notification.directive';
+import {CheSuccessNotification} from './notification/che-success-notification.directive';
 import {CheWarningNotification} from './notification/che-warning-notification.directive';
+import {CheInfoNotification} from './notification/che-info-notification.directive';
 import {ChePopup} from './popup/che-popup.directive';
 import {CheModalPopup} from './popup/che-modal-popup.directive';
 import {CheShowArea} from './show-area/che-show-area.directive';
@@ -190,8 +191,9 @@ export class WidgetConfig {
     register.directive('cheToolbar', CheToolbar);
     // notifications
     register.directive('cheErrorNotification', CheErrorNotification);
-    register.directive('cheInfoNotification', CheInfoNotification);
+    register.directive('cheSuccessNotification', CheSuccessNotification);
     register.directive('cheWarningNotification', CheWarningNotification);
+    register.directive('cheInfoNotification', CheInfoNotification);
     // wrapper for popup
     register.directive('chePopup', ChePopup);
     register.directive('cheModalPopup', CheModalPopup);
